# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

""" Bootspeed result parser. """


class MissingField(Exception):

    """ Module level exception. """

    pass


class BadMD5(Exception):

    """ Module level exception for bad md5. """

    pass


def verify_data(bootspeed_data):
    """ Verify that a data dictionary contains the needed fields.

    :param data: The data dictionary

    :raises: MissingField

    """
    fields = [
        'kernel',
        'kernel_init',
        'plumbing',
        'xorg',
        'desktop',
        'boot',
        'machine_name',
        'machine_mac',
        'image_build_number',
        'image_arch',
        'image_md5',
        'image_release',
        'image_variant',
        'ran_at',
    ]

    for field in fields:
        if field not in bootspeed_data:
            raise MissingField(
                "field {} is missing from input".format(field))

    field = 'image_build_number'
    build_number = bootspeed_data[field]
    if build_number == 'unknown':
        raise MissingField(
            "bad value {} for field {}".format(
                build_number,
                field,
            )
        )

    field = 'image_md5'
    md5 = bootspeed_data[field]
    if md5 == 'unknown':
        raise BadMD5(
            "bad value {} for field {}".format(
                md5,
                field,
            )
        )
