# QA Dashboard
# Copyright 2012-2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public
# License along with this program.  If not, see
# <http://www.gnu.org/licenses/>.

from django.core.management.base import BaseCommand

from smoke.models import (
    Run,
    Build,
    Result,
    ResultLog,
)

from sru.models import (
    Kernel,
    SRUResult,
    SRUResultLog,
)

from bootspeed.models import (
    Image,
    Machine,
    ImageResult,
    ImageResultLog,
    ImageMachineAgg,
    JobImage,
    ImageBuild,
)

from common.models import (
    Bug,
    JenkinsJob,
    JenkinsBuild,
)

from eventstat.models import eventstat_models

from power.models import (
    PowerImage,
    PowerLog,
    PowerMachine,
    PowerMetric,
)

from memory.models import (
    MemoryBuild,
    MemoryDetail,
    MemoryImage,
    MemoryLog,
    MemoryMachine,
    MemoryMetric,
    MemoryProcess,
    MemoryResult,
    MemoryUpgrade,
)

from common.management import process_class_list


class Command(BaseCommand):
    args = "[Class or app name] [Class or app name]..."
    help = "List items in the dashboard tables.  Useful for degugging."

    def handle(self, *args, **options):
        klasses = [
            Build,
            Run,
            Bug,
            Result,
            ResultLog,
            Kernel,
            SRUResult,
            SRUResultLog,
            Image,
            Machine,
            ImageResult,
            ImageResultLog,
            ImageMachineAgg,
            JobImage,
            ImageBuild,
            JenkinsJob,
            JenkinsBuild,
            PowerImage,
            PowerLog,
            PowerMachine,
            PowerMetric,
            MemoryBuild,
            MemoryDetail,
            MemoryImage,
            MemoryLog,
            MemoryMachine,
            MemoryMetric,
            MemoryResult,
            MemoryUpgrade,
            MemoryProcess,
        ]

        klasses += eventstat_models

        verbosity = int(options.get('verbosity'))

        klass_list = process_class_list(args)
        print("DEBUG: klass_list: {}".format(klass_list))

        if verbosity > 1:
            for klass in klasses:
                if klass_list and klass.__name__ not in klass_list:
                    continue

                print(klass.__name__)
                for item in klass.objects.all():
                    if hasattr(item, 'debug_str'):
                        print item.debug_str()
                    else:
                        print item

        for klass in klasses:
            if klass_list and klass.__name__ not in klass_list:
                continue

            print(klass.__name__)
            print("  {}".format(klass.objects.count()))
