/* # QA Dashboard
 * # Copyright 2012-2013 Canonical Ltd.
 *
 * # This program is free software: you can redistribute it and/or modify it
 * # under the terms of the GNU Affero General Public License version 3, as published
 * # by the Free Software Foundation.
 *
 * # This program is distributed in the hope that it will be useful, but
 * # WITHOUT ANY WARRANTY; without even the implied warranties of
 * # MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 * # PURPOSE.  See the GNU Affero General Public License for more details.
 *
 * # You should have received a copy of the GNU Affero General Public License along
 * # with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

  var MAX_COLUMNS = 60;
  var BAR_WIDTH;

  /* inspired by:
   * http://dygraphs.com/tests/plotters.html
   */
  function errorBarChartPlotter(e) {
    if (e.seriesIndex !== 0) return;

    var setCount = e.seriesCount;
    if (setCount < 4 || setCount > 6) {
      throw "Either 4, 5, or 6 values must be provided for error bar chart";
    }

    var speeds = [];
    var speed;
    var sets = e.allSeriesPoints;
    var area = e.plotArea;

    BAR_WIDTH = 3/4 * (sets[0][1].canvasx - sets[0][0].canvasx);

    for (var p = 1; p < sets[0].length; p++) {
      // skip null values
      if (isNaN(sets[0][p].yval)) {
        continue;
      }

      speed = {
        min: sets[0][p].yval,
        avg: sets[1][p].yval,
        max: sets[2][p].yval,
        std: sets[3][p].yval,
        minY: sets[0][p].y,
        avgY: sets[1][p].y,
        maxY: sets[2][p].y,
        stdY: sets[3][p].y,
      };
      if (setCount >= 5) {
        speed.release = sets[4][p].yval;
        speed.releaseY = sets[4][p].y;
      }
      if (setCount >= 6) { // duration
        speed.duration = sets[5][p].yval;
        speed.durationY = sets[5][p].y;
      }
      speeds.push(speed);
    }

    var ctx = e.drawingContext;
    ctx.strokeStyle = 'rgba(32, 32, 32, 0.75)';
    ctx.lineWidth = 1.0;

    var HASH_WIDTH = 4;
    var y_bottom = e.dygraph.toDomYCoord(0); // see http://dygraphs.com/jsdoc/symbols/Dygraph.html#toDomYCoord

    var std_prev_x = 0;
    var std_prev_y = 0;
    var duration_prev_x = 0;
    var duration_prev_y = 0;

    for (p = 0; p < speeds.length; p++) {

      speed = speeds[p];
      var has_duration = speed.hasOwnProperty('durationY');
      var topY = area.h * speed.maxY + area.y;
      var bottomY = area.h * speed.minY + area.y;
      var centerX = area.x + sets[0][p + 1].x * area.w;
      var stdY = area.h * speed.stdY + area.y;
      if (has_duration) {
          var durationY = area.h * speed.durationY + area.y;
      }

      // Don't draw stddev line until first column
      if (p == 0) {
        std_prev_x = centerX;
        std_prev_y = stdY;
        if (has_duration) {
           duration_prev_x = centerX;
           duration_prev_y = durationY;
        }
      }

      // Draw the bar first
      var bodyY = area.h * speed.avgY + area.y;
      ctx.fillStyle = 'rgba(253, 186, 144, 1.0)';
      ctx.fillRect(centerX - BAR_WIDTH / 2, bodyY, BAR_WIDTH, y_bottom - bodyY);

      ctx.strokeStyle = 'rgba(0, 0, 0, 1.00)';
      // Draw error bar lines.
      ctx.beginPath();
      ctx.moveTo(centerX, topY);
      ctx.lineTo(centerX, bottomY);

      // Draw top hash
      ctx.moveTo(centerX - HASH_WIDTH / 2, topY);
      ctx.lineTo(centerX + HASH_WIDTH / 2, topY);

      // Draw bottom hash
      ctx.moveTo(centerX - HASH_WIDTH / 2, bottomY);
      ctx.lineTo(centerX + HASH_WIDTH / 2, bottomY);

      ctx.closePath();

      ctx.stroke();

      // Draw stddev line
      ctx.beginPath();
      ctx.moveTo(std_prev_x, std_prev_y);
      ctx.lineTo(centerX, stdY);
      ctx.closePath();
      // Store old values
      std_prev_x = centerX;
      std_prev_y = stdY;
      ctx.stroke();

      // Draw dduration line
      if (has_duration) {
          ctx.strokeStyle = 'rgba(0, 0, 255, 1.00)';
          ctx.beginPath();
          ctx.moveTo(duration_prev_x, duration_prev_y);
          ctx.lineTo(centerX, durationY);
          ctx.closePath();
          // Store old values
          duration_prev_x = centerX;
          duration_prev_y = durationY;
          ctx.stroke();
      }
    }
    ctx.strokeStyle = 'rgba(0, 0, 0, 1.00)';
    ctx.lineWidth = 1.0;

    // XXX: set line color
    if (speeds[0].release > 0) {
      ctx.beginPath();
      ctx.moveTo(0, area.h * speeds[0].releaseY + area.y);
      ctx.lineTo(area.x + area.w, area.h * speeds[0].releaseY + area.y);
      ctx.closePath();
      ctx.stroke();
    }
  }

  function draw_bootspeed_graph(api_url, div_id) {
    YUI().use('io-base', 'json-parse', function (Y) {
      Y.io(api_url, {
        method: 'GET',
        on: {
          success: function (id, result) {
            var bootspeedData = Y.JSON.parse(result.responseText);

            var values = Array();
            var values_labels = Array();

            if (bootspeedData.last_release_avg > 0) {
              values.push([0, null, null, null, null, null]);
            } else {
              values.push([0, null, null, null, null]);
            }
            values_labels.push("");

            for (x in bootspeedData.image_data) {
              var record = bootspeedData.image_data[x];
              var last_release_avg = bootspeedData.last_release_avg
              var last_release_name = bootspeedData.last_release_name
              var row_data = [parseInt(x) + 1, record.min, record.avg, record.max, record.std];
              var labels = ["x", "min", "avg", "max", "stddev"]
              if (last_release_avg > 0) {
                row_data.push(last_release_avg);
                labels.push(last_release_name);
              }

              values.push(row_data);
              values_labels.push(record.build_number)
            }

            if (bootspeedData.last_release_avg > 0) {
              values.push([values.length, null, null, null, null, null]);
            } else {
              values.push([values.length, null, null, null, null]);
            }
            values_labels.push("");

            g = new Dygraph(
              document.getElementById(div_id),
              values,
              {
                width: 800,
                height: 500,
                plotter: errorBarChartPlotter,
                labels: labels,
                axisLabelFontSize: 12,
                xAxisHeight: 80,
                rightGap: 10,
                drawXGrid: false,
                drawYGrid: false,
                ylabel: "seconds",
                axes: {
                  x: {
                    pixelsPerLabel: 15,
                    valueFormatter: function(d) {
                      return values_labels[d];
                    },
                    axisLabelFormatter: function(d, gran) {
                      if (d in values_labels)
                        return values_labels[d];
                      else
                        return "";
                    }
                  }
                }
              }
            );
          }
        }
      });
    });
   };


  function draw_power_graph(api_url, div_id, label_id, big) {
    if (typeof(big) === 'undefined') big = false;
    YUI().use('io-base', 'json-parse', function (Y) {
      Y.io(api_url, {
        method: 'GET',
        on: {
          success: function (id, result) {
            var data = Y.JSON.parse(result.responseText);

            var values = Array();
            var values_labels = Array();

            var graphs = Array();

            if (data.last_release_avg > 0) {
              values.push([0, null, null, null, null, null, null, null]);
            } else {
              values.push([0, null, null, null, null, null, null]);
            }
            values_labels.push("");

            for (x in data.image_data) {
              var record = data.image_data[x];
              var last_release_avg = data.last_release_avg
              var last_release_name = data.last_release_name
              var row_data = [parseInt(x) + 1, record.min, record.avg, record.max, record.std];
              var labels = ["x", "min", "avg", "max", "stddev"]
              if (last_release_avg > 0) {
                row_data.push(last_release_avg);
                labels.push(last_release_name);
              } else {
                  row_data.push(null);
                  labels.push("");
              }

              row_data.push(record.duration);
              labels.push("duration");

              values.push(row_data);
              values_labels.push(record.build_number)
            }

            if (data.last_release_avg > 0) {
              values.push([values.length, null, null, null, null, null, null, null]);
            } else {
              values.push([values.length, null, null, null, null, null, null]);
            }
            values_labels.push("");

            var width = 400;
            var height = 300;

            if (big) {
               width = 800;
               height = 400;
            }

            g = new Dygraph(
              document.getElementById(div_id),
              values,
              {
                width: width,
                height: height,
                plotter: errorBarChartPlotter,
                labels: labels,
                labelsDiv: document.getElementById(label_id),
                axisLabelFontSize: 12,
                xAxisHeight: 80,
                rightGap: 10,
                drawXGrid: false,
                drawYGrid: false,
                ylabel: "mA",
                y2label: "seconds",
                hideOverlayOnMouseOut: false,
                legend: "always",
                'duration': {
                    axis: {
                        digitsAfterDecimal: 0,
                        valueRange: [0,1000]
                    }
                },
                unhighlightCallback: function(me, e) {
                    if (me.isZoomed('x')) return;
                    var range = me.xAxisRange();
                    var last_row = me.numRows() - 2;
                    me.setSelection(last_row);
                },
                //yAxisLabelWidth: 60,
                axes: {
                  x: {
                    pixelsPerLabel: 15,
                    valueFormatter: function(d) {
                      return values_labels[d];
                    },
                    axisLabelFormatter: function(d, gran) {
                      if (d in values_labels)
                        return values_labels[d];
                      else
                        return "";
                    }
                  },
                  y2: {
                    ticker: function(min, max, pixels, opts, dygraph, vals) {
                      return [
                        {v:0, label:"0"},
                        {v:100, label:"100"},
                        {v:200, label:"200"},
                        {v:300, label:"300"},
                        {v:400, label:"400"},
                        {v:500, label:"500"},
                        {v:600, label:"600"},
                        {v:700, label:"700"},
                        {v:800, label:"800"},
                        {v:900, label:"900"}
                      ];
                    }
                  }
                }
              }
            );

            var rows = g.numRows();
            g.setSelection(rows - 2); // last data row
            graphs.push(g);
          }
        }
      });
    });
  };

  function draw_memory_graph(api_url, div_id, label_id, big) {
    if (typeof(big) === 'undefined') big = false;
    YUI().use('io-base', 'json-parse', function (Y) {
      Y.io(api_url, {
        method: 'GET',
        on: {
          success: function (id, result) {
            var data = Y.JSON.parse(result.responseText);

            var values = Array();
            var values_labels = Array();

            var graphs = Array()

            if (data.last_release_avg > 0) {
              values.push([0, null, null, null, null, null, null]);
            } else {
              values.push([0, null, null, null, null, null]);
            }
            values_labels.push("");

            for (x in data.image_data) {
              var record = data.image_data[x];
              var last_release_avg = data.last_release_avg
              var last_release_name = data.last_release_name
              var row_data = [parseInt(x) + 1, record.min, record.avg, record.max, record.std];
              var labels = ["x", "min", "avg", "max", "stddev"]
              if (last_release_avg > 0) {
                row_data.push(last_release_avg);
                labels.push(last_release_name);
              } else {
                  row_data.push(null);
                  labels.push("");
              }

              values.push(row_data);
              values_labels.push(record.build_number)
            }

            if (data.last_release_avg > 0) {
              values.push([values.length, null, null, null, null, null, null]);
            } else {
              values.push([values.length, null, null, null, null, null]);
            }
            values_labels.push("");

            var width = 400;
            var height = 300;

            if (big) {
               width = 800;
               height = 400;
            }

            g = new Dygraph(
              document.getElementById(div_id),
              values,
              {
                width: width,
                height: height,
                plotter: errorBarChartPlotter,
                labels: labels,
                labelsDiv: document.getElementById(label_id),
                axisLabelFontSize: 12,
                xAxisHeight: 80,
                rightGap: 10,
                drawXGrid: false,
                drawYGrid: false,
                labelsKMG2: true,
                hideOverlayOnMouseOut: false,
                legend: "always",
                unhighlightCallback: function(me, e) {
                    if (me.isZoomed('x')) return;
                    var range = me.xAxisRange();
                    var last_row = me.numRows() -2;
                    me.setSelection(last_row);
                },
                axes: {
                  x: {
                    pixelsPerLabel: 15,
                    valueFormatter: function(d) {
                      return values_labels[d];
                    },
                    axisLabelFormatter: function(d, gran) {
                      if (d in values_labels)
                        return values_labels[d];
                      else
                        return "";
                    }
                  }
                }
              }
            );

            var rows = g.numRows();
            g.setSelection(rows - 2); // last data row
            graphs.push(g);
          }
        }
      });
    });
   };

  function draw_memory_process_graph(api_url, div_id, label_id, big) {
    if (typeof(big) === 'undefined') big = false;
    YUI().use('io-base', 'json-parse', function (Y) {
      Y.io(api_url, {
        method: 'GET',
        on: {
          success: function (id, result) {
            var data = Y.JSON.parse(result.responseText);

            var values = Array();
            var values_labels = Array();

            var graphs = Array()

            if (data.last_release_avg > 0) {
              values.push([0, null, null, null, null, null, null]);
            } else {
              values.push([0, null, null, null, null, null]);
            }
            values_labels.push("");

            for (x in data.proc_data) {
              var record = data.proc_data[x];
              var last_release_avg = data.last_release_avg
              var last_release_name = data.last_release_name
              var row_data = [parseInt(x) + 1, record.min, record.avg, record.max, record.std];
              var labels = ["x", "min", "avg", "max", "stddev"]
              if (last_release_avg > 0) {
                row_data.push(last_release_avg);
                labels.push(last_release_name);
              } else {
                  row_data.push(null);
                  labels.push("");
              }

              values.push(row_data);
              values_labels.push(record.build_number)
            }

            if (data.last_release_avg > 0) {
              values.push([values.length, null, null, null, null, null, null]);
            } else {
              values.push([values.length, null, null, null, null, null]);
            }
            values_labels.push("");

            var width = 400;
            var height = 300;

            if (big) {
               width = 800;
               height = 400;
            }

            g = new Dygraph(
              document.getElementById(div_id),
              values,
              {
                width: width,
                height: height,
                plotter: errorBarChartPlotter,
                labels: labels,
                labelsDiv: document.getElementById(label_id),
                axisLabelFontSize: 12,
                xAxisHeight: 80,
                rightGap: 10,
                drawXGrid: false,
                drawYGrid: false,
                labelsKMG2: true,
                hideOverlayOnMouseOut: false,
                legend: "always",
                unhighlightCallback: function(me, e) {
                    if (me.isZoomed('x')) return;
                    var range = me.xAxisRange();
                    var last_row = me.numRows() -2;
                    me.setSelection(last_row);
                },
                axes: {
                  x: {
                    pixelsPerLabel: 15,
                    valueFormatter: function(d) {
                      return values_labels[d];
                    },
                    axisLabelFormatter: function(d, gran) {
                      if (d in values_labels)
                        return values_labels[d];
                      else
                        return "";
                    }
                  }
                }
              }
            );

            var rows = g.numRows();
            g.setSelection(rows - 2); // last data row
            graphs.push(g);
          }
        }
      });
    });
   };

function show_memory_popup(elem_id, process_name, url, label_id, chart_id, chart_label_id) {
  elem = document.getElementById(elem_id);
  elem.style.display = "block";

  label = document.getElementById(label_id);
  if (label !== null) {
    label.innerHTML = "<h2>" + process_name + "</h2>";
  }

  draw_memory_process_graph(url, chart_id, chart_label_id, true);
}

function hide_popup(elem_id) {
  elem = document.getElementById(elem_id);
  elem.style.display = "none";
}
