# QA Dashboard
# Copyright 2012-2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django import template
from django.template.defaultfilters import stringfilter

from common.models import Bug

register = template.Library()


def pass_rate_color(value):
    """Colouring for pass rates based on css classes"""
    if value > 0.97:
        return "green"
    elif value > 0.6:
        return "yellow"
    else:
        return "red"

register.filter('pass_rate_color', pass_rate_color)


def pass_fail_color(value):
    """ Coloring for pass/fail values.  """

    # True for failed, False for passed.
    if value:
        return "red"
    else:
        return "green"

register.filter('pass_fail_color', pass_fail_color)


def not_zero_color(value):
    """ Coloring for count values.  """

    if value == 0:
        return "red"
    else:
        return "green"

register.filter('not_zero_color', not_zero_color)


def bug_list(bugs, prefix=""):
    html = ""

    bug_numbers = []

    # handle a single bug and a list of bugs.
    if isinstance(bugs, Bug):
        bugs = [bugs]

    for bug in bugs:
        if bug.bug_no in bug_numbers:
            continue

        bug_numbers.append(bug.bug_no)
        html = " ".join([
            html,
            '<a href="https://bugs.launchpad.net/bugs/{}/">{}LP:#{}</a>'.format(bug.bug_no, prefix, bug.bug_no)
        ])

    return html

register.filter('bug_list', bug_list)


def binary_suffix(num):
    """ Assumes default units are K. """

    LIMIT = 1024
    orig_num = num

    suffixes = ['K', 'M', 'G', 'T', 'P']
    index = 0

    while num >= LIMIT:
        index += 1
        num = float(num) / LIMIT

    if index >= len(suffixes):
        index = 0
        num = orig_num

    # format float values but avoid scientific notation.
    # inspired by: http://stackoverflow.com/a/2440786
    num = "{:.2f}".format(num).rstrip('0').rstrip('.')
    return "{}{}".format(num, suffixes[index])

register.filter('binary_suffix', binary_suffix)
