# QA Dashboard
# Copyright 2012-2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf import settings
from django.template import Template, Context
from django.test import TestCase

from common.templatetags.instance import instance_banner


class TestInstanceTags(TestCase):

    def setUp(self):
        super(TestInstanceTags, self).setUp()
        self._old_configuration = settings.CONFIGURATION

    def tearDown(self):
        settings.CONFIGURATION = self._old_configuration
        super(TestInstanceTags, self).tearDown()

    def assertIn(self, item1, item2, message=None):
        """Assert that 'item1' is contained in 'item2'."""
        if item1 not in item2:
            raise self.failureException(
                message or "%r not in %r" % (
                    item1,
                    item2
                )
            )

    def test_instance_banner_tag_exports_details(self):
        """
        The 'instance_banner' tag should make settings.CONFIGURATION
        available to the template.
        """
        self.assertEqual(
            {'configuration': 'staging'},
            instance_banner()
        )

    def test_instance_banner_tag_rendered_in_development(self):
        """
        The instance tag displays a banner if the configuration is
        staging.
        """
        rendered = Template("{% load instance %}"
                            "{% instance_banner %}").render(Context())
        self.assertIn(
            "<p>You are accessing the <strong>staging"
            "</strong> instance of the <strong>QA Dashboard</strong>",
            rendered
        )

    def test_instance_banner_hidden_in_production(self):
        """
        The instance tag renders nothing if the configuration is 'production'.
        """
        settings.CONFIGURATION = "production"
        rendered = Template(
            "{% load instance %}"
            "{% instance_banner %}"
        ).render(Context())
        self.assertEqual(u"\n", rendered)
