# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from eventstat.models import (
    EventstatImage,
    EventstatMachine,
    EventstatMetric,
    EventstatUpgrade,
)


def get_metrics(arch=None, image=None, upgrade=None):

    metrics = EventstatMetric.objects.filter(publish=True)

    if arch is not None:
        metrics = metrics.filter(arch=arch)

    if image is not None:
        metrics = metrics.filter(image=image)

    if upgrade is not None:
        metrics = metrics.filter(upgrade=upgrade)

    return metrics


def get_images(arch=None):

    images = EventstatImage.objects.filter(publish=True)

    if arch is not None:
        images = images.filter(arch=arch)

    return images


def get_upgrades(arch=None):

    upgrades = EventstatUpgrade.objects.filter(publish=True)

    if arch is not None:
        upgrades = upgrades.filter(arch=arch)

    return upgrades


def get_arches():
    arches = []

    image_arches = EventstatMetric.objects.values('image__arch')
    image_arches = image_arches.distinct().exclude(publish=False)
    image_arches = image_arches.exclude(image__arch=None)

    for arch in image_arches.iterator():
        arches.append(arch['image__arch'])

    upgrade_arches = EventstatMetric.objects.values('upgrade__arch')
    upgrade_arches = upgrade_arches.distinct().exclude(publish=False)
    upgrade_arches = upgrade_arches.exclude(upgrade__arch=None)

    for arch in upgrade_arches:
        if arch['upgrade__arch'] not in arches:
            arches.append(arch['upgrade__arch'])

    return sorted(arches)


def get_machines(arch=None):

    machines = []

    image_machines = EventstatMachine.objects.filter(
        publish=True,
        eventstatmetric__isnull=False,
    )
    image_machines = image_machines.distinct()
    image_machines = image_machines.filter(eventstatmetric__upgrade=None)

    if arch is not None:
        image_machines = image_machines.filter(
            eventstatmetric__image__arch=arch,
        )

    upgrade_machines = EventstatMachine.objects.filter(
        publish=True,
        eventstatmetric__isnull=False,
    )
    upgrade_machines = upgrade_machines.distinct()
    upgrade_machines = upgrade_machines.filter(eventstatmetric__image=None)

    if arch is not None:
        upgrade_machines = upgrade_machines.filter(
            eventstatmetric__upgrade__arch=arch,
        )

    machines = image_machines | upgrade_machines

    return machines
