# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from memory.models import (
    MemoryUpgrade,
    MemoryImage,
    MemoryMachine,
    MemoryLog,
    MemoryDetail,
    MemoryResult,
    MemoryMetric,
    MemoryBuild,
)

from django.contrib import admin


class MemoryUpgradeAdmin(admin.ModelAdmin):
    list_display = (
        'release',
        'variant',
        'arch',
        'from_release',
        'date',
    )

    list_filter = [
        'release',
        'variant',
        'arch',
        'from_release',
        'date',
    ]
    search_fields = [
        'release',
        'variant',
        'arch',
        'from_release',
    ]
    ordering = ['-date']


class MemoryMachineAdmin(admin.ModelAdmin):
    list_display = ('name', 'mac_address')
    search_fields = ['name', 'mac_address']


class MemoryLogAdmin(admin.ModelAdmin):
    list_display = ('name', 'path')
    search_fields = ['name', 'path']


class MemoryMetricAdmin(admin.ModelAdmin):
    list_display = (
        'name',
        'image',
        'upgrade',
        'minimum',
        'maximum',
        'average',
        'stddev',
    )
    list_filter = [
        'name',
        'image',
        'upgrade',
    ]
    search_fields = [
        'upgrade',
        'name',
    ]


class MemoryImageAdmin(admin.ModelAdmin):
    list_display = (
        'release',
        'variant',
        'arch',
        'build_number',
        'image_type',
    )
    list_filter = [
        'release',
        'variant',
        'arch',
        'build_number',
    ]
    search_fields = [
        'release',
        'variant',
        'arch',
        'build_number',
    ]


class MemoryDetailAdmin(admin.ModelAdmin):
    list_display = (
        'image',
        'upgrade',
        'name',
        'command',
    )


class MemoryResultAdmin(admin.ModelAdmin):
    list_display = (
        'image',
        'upgrade',
        'machine',
        'kernel',
    )


class MemoryBuildAdmin(admin.ModelAdmin):
    list_display = (
        'image',
        'upgrade',
        'build',
    )


admin.site.register(MemoryUpgrade, MemoryUpgradeAdmin)
admin.site.register(MemoryMachine, MemoryMachineAdmin)
admin.site.register(MemoryLog, MemoryLogAdmin)
admin.site.register(MemoryMetric, MemoryMetricAdmin)
admin.site.register(MemoryImage, MemoryImageAdmin)
admin.site.register(MemoryDetail, MemoryDetailAdmin)
admin.site.register(MemoryResult, MemoryResultAdmin)
admin.site.register(MemoryBuild, MemoryBuildAdmin)
