# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public
# License along with this program.  If not, see
# <http://www.gnu.org/licenses/>.

import logging

from django.core.management.base import BaseCommand
from django.db import models

from memory.models import (
    MemoryDetail,
    MemoryProcess,
)


class Command(BaseCommand):
    help = "Do process calculations."

    def _aggregate(self, name, image, upgrade, machine):
        """ Aggregate values by name. """

        details = MemoryDetail.objects.filter(
            name=name,
            image=image,
            upgrade=upgrade,
            machine=machine,
        )

        latest_ran_at = details.aggregate(
            models.Max('ran_at')
        )['ran_at__max']

        proc, new_proc = MemoryProcess.objects.get_or_create(
            process=name,
            image=image,
            upgrade=upgrade,
            machine=machine,
            defaults=dict(
                ran_at=latest_ran_at,
            ),
        )

        detail_agg = details.aggregate(
            models.Avg('pss'),
            models.Max('pss'),
            models.Min('pss'),
            models.StdDev('pss'),
        )

        proc.stddev = detail_agg['pss__stddev']
        proc.minimum = detail_agg['pss__min']
        proc.maximum = detail_agg['pss__max']
        proc.average = detail_agg['pss__avg']
        proc.name = "pss"

        proc.save()

        return proc

    def handle(self, *args, **options):

        verbosity = int(options.get('verbosity'))

        log_level = logging.WARN
        if verbosity == 2:
            log_level = logging.INFO
        if verbosity > 2:
            log_level = logging.DEBUG

        logging.basicConfig(level=log_level)

        details = MemoryDetail.objects.filter(publish=True)
        details = details.distinct('name', 'image', 'upgrade', 'machine')

        for detail in details.iterator():
            logging.info("name: {}".format(detail.name))
            proc = self._aggregate(
                detail.name,
                detail.image,
                detail.upgrade,
                detail.machine,
            )

        for proc in MemoryProcess.objects.all():
            logging.info("proc: {} - {}".format(proc.process, proc.name))
