# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public
# License along with this program.  If not, see
# <http://www.gnu.org/licenses/>.

import logging

from django.core.management.base import BaseCommand
from django.db import models

from memory.models import (
    MemoryDetail,
    MemoryResult,
)


class Command(BaseCommand):
    help = "Do result calculations."

    def _aggregate(self, result):
        """ Aggregate values by name. """

        details = MemoryDetail.objects.filter(
            result=result,
        )

        if details.count() == 0:
            result.delete()
            return

        details = details.aggregate(models.Sum('pss'))

        result.value = details['pss__sum']
        logging.info("result.value: {}".format(result.value))
        result.publish = True
        result.save()

        return result

    def handle(self, *args, **options):

        verbosity = int(options.get('verbosity'))

        log_level = logging.WARN
        if verbosity == 2:
            log_level = logging.INFO
        if verbosity > 2:
            log_level = logging.DEBUG

        logging.basicConfig(level=log_level)

        results = MemoryResult.objects.filter(
            name='pss',
        )

        logging.info("results: {}".format(results))
        for result in results.iterator():
            logging.info("name: {}".format(result.name))
            res = self._aggregate(result)

            logging.info("result: {}".format(res))
