import django_tables2 as tables
from django_tables2.utils import Accessor as A

from memory.models import MemoryResult


class ResultTable(tables.Table):

    class Meta:
        attrs = {'class': 'basic wide'}
        model = MemoryResult
        fields = (
            "name",
            "kernel",
            "value",
            "logs",
            "detail_count",
        )

    name = tables.Column()
    kernel = tables.Column()


class ImageResultTable(ResultTable):
    image__build_number = tables.LinkColumn(
        'memory.views.machine_image_details',
        accessor='image.build_number',
        kwargs={
            'result_id': A('id'),
            'arch': A('image.arch'),
            'machine_id': A('machine.id'),
        },
        verbose_name="Build Number",
    )
    logs = tables.TemplateColumn(
        '{{ record.log_link|safe }}',
        sortable=False,
    )
    detail_count = tables.Column(
        verbose_name='Processes',
        attrs={'td': {'class': 'num'}},
        sortable=False,
    )
    value = tables.TemplateColumn(
        '{% load dashboard_extras %}{{ record.value|binary_suffix }}',
        attrs={'td': {'class': 'num'}}
    )

    class Meta(ResultTable.Meta):
        attrs = {'class': 'basic wide'}
        order_by = ('-image__build_number',)
        sequence = (
            "image__build_number",
        )


class UpgradeResultTable(ResultTable):
    upgrade__date = tables.LinkColumn(
        'memory.views.machine_upgrade_details',
        accessor='upgrade.date',
        kwargs={
            'arch': A('upgrade.arch'),
            'machine_id': A('machine.id'),
            'result_id': A('id'),
        },
        verbose_name='Upgrade Date',
    )
    logs = tables.TemplateColumn(
        '{{ record.log_link|safe }}',
        sortable=False,
    )
    detail_count = tables.Column(
        verbose_name='Processes',
        attrs={'td': {'class': 'num'}},
        sortable=False,
    )
    value = tables.TemplateColumn(
        '{% load dashboard_extras %}{{ record.value|binary_suffix }}',
        attrs={'td': {'class': 'num'}}
    )


    class Meta(ResultTable.Meta):
        attrs = {'class': 'basic wide'}
        order_by = ('-upgrade__date',)
        sequence = (
            "upgrade__date",
        )


class DetailTotalTable(tables.Table):
    pss = tables.TemplateColumn(
        '{% load dashboard_extras %}{{ record.pss|binary_suffix }}',
        verbose_name="PSS",
        attrs={'td': {'class': 'num'}},
    )

    class Meta:
        attrs = {'class': 'basic wide'}


class DetailTable(tables.Table):
    name = tables.TemplateColumn(
        '<a href=\'javascript:show_memory_popup("mem_popup", "{{ record.name }}", "{{ record.url }}", "label", "chart", "chart_label")\'>{{ record.name}}</a>',
    )
    command = tables.Column()
    pss = tables.TemplateColumn(
        '{% load dashboard_extras %}{{ record.pss|binary_suffix }}',
        verbose_name="PSS",
        attrs={'td': {'class': 'num'}},
    )
    movement = tables.TemplateColumn(
        '<div class="{{ record.movement }}">&nbsp;</div>',
        verbose_name="Direction",
    )
    change = tables.TemplateColumn(
        '{% load dashboard_extras %}{{ record.change|binary_suffix }}',
        verbose_name="Average Change",
        attrs={'td': {'class': 'num'}},
    )

    class Meta:
        attrs = {'class': 'basic wide'}
        order_by = ('-change', '-pss',)
        sortable = True
