# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License version
# 3, as published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public
# License along with this program.  If not, see
# <http://www.gnu.org/licenses/>.

import logging
import re
import urllib2

from common.utils import regexes
from common.management import (
    jenkins_get,
    parse_build_description,
)


def _get_file_contents(path):
    try:
        response = jenkins_get(path, as_json=False)
    except urllib2.HTTPError:
        response = ""

    return response


def get_image_build_number(build):
    """ Try to determine the build number for the image. """

    data = parse_build_description(build['description'])

    if data['build_number'] is not None:
        return data['build_number']

    path = "{}artifact/media-info".format(build['url'])
    m = regexes['build-number'].match(_get_file_contents(path))
    if m:
        return m.group(1)

    path = "{}console".format(build['url'])
    content = _get_file_contents(path)
    m = regexes['console-build-number'].search(content)
    if m:
        logging.info("found match in console")
        return m.group(1)
    else:
        logging.info("didn't find match in console")

    return "UNKNOWN"


def get_run_number(path, prefix=''):
    """ Extract the run number from an artifact path. """

    regex = re.compile(ur'^{}(\d*)\/'.format(prefix))

    m = regex.match(path)

    return m.group(1) if m else None
