# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public
# License along with this program.  If not, see
# <http://www.gnu.org/licenses/>.

from django.db import models

from common.models import (
    DashboardBaseModel,
)


# Common Performance Models.
class ImageBase(DashboardBaseModel):
    """ Image base class. """

    TYPE_CHOICES = (
        (u'daily', u'Daily Image'),
        (u'release', u'Release Image'),
    )

    class Meta:
        abstract = True
        unique_together = ('release', 'variant', 'arch', 'build_number')

    release = models.CharField(max_length=200)
    variant = models.CharField(max_length=200)
    arch = models.CharField(max_length=200)
    md5 = models.CharField(max_length=200, unique=True)
    build_number = models.CharField(max_length=50)
    image_type = models.CharField(max_length=10, choices=TYPE_CHOICES,
                                  default=TYPE_CHOICES[0][0])

    def __unicode__(self):
        return "{}-{}-{}-{}".format(
            self.release,
            self.variant,
            self.arch,
            self.build_number,
        )


class UpgradeBase(DashboardBaseModel):
    """ Infomation about an upgraded system. """

    class Meta:
        abstract = True

    release = models.CharField(max_length=200)
    variant = models.CharField(max_length=200)
    arch = models.CharField(max_length=200)
    from_release = models.CharField(max_length=200)
    date = models.DateTimeField("date upgraded")

    def __unicode__(self):
        return "Upgrade from {} to {} on {} {}".format(
            self.from_release,
            self.release,
            self.variant,
            self.arch,
        )


class MachineBase(DashboardBaseModel):
    """ Machine base class. """

    class Meta:
        abstract = True

    name = models.CharField(max_length=200, unique=True)
    mac_address = models.CharField(max_length=200)

    def __unicode__(self):
        return self.name


class MetricBase(DashboardBaseModel):
    """ Metric model. """

    class Meta:
        abstract = True

    name = models.CharField(max_length=200)
    minimum = models.FloatField(default=0)
    maximum = models.FloatField(default=0)
    average = models.FloatField(default=0)
    stddev = models.FloatField(default=0)
    ran_at = models.DateTimeField('date run')
    jenkins_url = models.URLField(null=True)

    def __unicode__(self):
        return "min: {}, max: {}, avg: {}, stddev: {}".format(
            self.minimum,
            self.maximum,
            self.average,
            self.stddev,
        )


class ResultBase(DashboardBaseModel):
    """ Result model. """

    class Meta:
        abstract = True

    name = models.CharField(max_length=200)
    value = models.FloatField()
    ran_at = models.DateTimeField('date run')
    jenkins_url = models.URLField(null=True)

    def __unicode__(self):
        return "name: {}, value: {}".format(
            self.name,
            self.value,
        )
