# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from power.models import (
    PowerImage,
    PowerMachine,
    PowerLog,
    PowerMetric,
)

from django.contrib import admin


class PowerImageAdmin(admin.ModelAdmin):
    list_display = (
        'build_number',
        'release',
        'variant',
        'arch',
        'image_type',
    )

    list_filter = [
        'release',
        'variant',
        'arch',
        'image_type',
    ]
    search_fields = [
        'release',
        'variant',
        'arch',
        'build_number',
    ]
    ordering = ['-build_number']


class PowerMachineAdmin(admin.ModelAdmin):
    list_display = ('name', 'mac_address')
    search_fields = ['name', 'mac_address']


class PowerLogAdmin(admin.ModelAdmin):
    list_display = ('name', 'path')
    search_fields = ['name', 'path']


class PowerMetricAdmin(admin.ModelAdmin):
    list_display = (
        'name',
        'image',
        'minimum',
        'maximum',
        'average',
        'stddev',
        'duration',
    )
    list_filter = [
        'name',
        'image__release',
        'image__variant',
        'image__arch',
        'machine',
    ]
    search_fields = [
        'image__build_number',
        'image__release',
        'image__variant',
        'image__arch',
        'name',
    ]
    date_hierarchy = 'ran_at'
    ordering = ['-image__build_number']

admin.site.register(PowerImage, PowerImageAdmin)
admin.site.register(PowerMachine, PowerMachineAdmin)
admin.site.register(PowerLog, PowerLogAdmin)
admin.site.register(PowerMetric, PowerMetricAdmin)
