# QA Dashboard

# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import json
from django.views.decorators.http import require_GET
from django.shortcuts import get_object_or_404

from common.utils import (
    JSONResponse,
    MySerializer,
)

from power.models import (
    PowerImage,
    PowerMachine,
    PowerMetric,
)

MAX_RESULTS = 180


@require_GET
def image_machine_metrics(request, image_id, machine_id):
    metrics = PowerMetric.objects.filter(image=image_id, machine=machine_id)

    serializer = MySerializer(use_extra_fields=True)
    data = serializer.serialize(metrics)

    return JSONResponse(data)


@require_GET
def images(request, arch=None):
    images = PowerImage.objects.all()

    if arch is not None:
        images = images.filter(arch=arch)

    serializer = MySerializer(use_extra_fields=True)
    data = serializer.serialize(images)

    return JSONResponse(data)


@require_GET
def machines(request):
    machines = PowerMachine.objects.filter(publish=True)

    serializer = MySerializer(use_extra_fields=True)
    data = serializer.serialize(machines)

    return JSONResponse(data)


@require_GET
def image_detail(request, image_id):
    image = get_object_or_404(PowerImage, id=image_id)

    serializer = MySerializer(use_extra_fields=True)
    data = serializer.serialize([image])

    return JSONResponse(data)


@require_GET
def machine_detail(request, machine_id):
    machine = get_object_or_404(PowerMachine, id=machine_id)

    serializer = MySerializer(use_extra_fields=True)
    data = serializer.serialize([machine])

    return JSONResponse(data)


@require_GET
def machine_metric_results(request, name, machine_id, arch):
    res = PowerMetric.objects.filter(
        name=name,
        machine=machine_id,
        image__arch=arch,
    ).order_by('image__build_number')[:MAX_RESULTS]

    last_releases = PowerImage.objects.filter(
        powermetric__machine=machine_id,
        arch=arch, image_type='release',
    ).order_by('-build_number')

    if last_releases.count() > 0:
        last_release_avg = last_releases[0].boot_avg
        last_release_name = last_releases[0].image.release
    else:
        last_release_avg = 0.0
        last_release_name = 'Unknown'

    bundle = {
        'last_release_avg': last_release_avg,
        'last_release_name': last_release_name,
    }

    image_data = []
    for r in res:
        image_info = dict(
            bottom=r.minimum,
            min=r.minimum,
            max=r.maximum,
            avg=r.average,
            std=r.stddev,
            duration=r.duration,
            build_number=r.image.build_number,
        )
        image_data.append(image_info)

    bundle['count'] = res.count()
    bundle['image_data'] = image_data
    data = json.dumps(bundle)

    return JSONResponse(data)
