# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.db import models

from common.models import DashboardBaseModel

from performance.models import (
    ImageBase,
    MachineBase,
    MetricBase,
)


class PowerImage(ImageBase):
    """ Power Image model. """

    class Meta:
        db_table = "power_images"

    @property
    def metric_count(self):
        return self.powermetric_set.count()

    @property
    def metrics(self):
        return self.powermetric_set.all()


class PowerMachine(MachineBase):
    """ Power Machine model. """

    class Meta:
        db_table = "power_machines"

    @property
    def metric_count(self):
        return self.powermetric_set.count()

    @property
    def metrics(self):
        return self.powermetric_set.all()


class PowerLog(DashboardBaseModel):
    """ Power logs for a build. """

    class Meta:
        db_table = "power_logs"

    path = models.CharField(max_length=512)
    name = models.CharField(max_length=100)


class PowerMetric(MetricBase):
    """ Power metric model. """

    class Meta:
        db_table = "power_metrics"

    image = models.ForeignKey(PowerImage)
    machine = models.ForeignKey(PowerMachine)
    kernel = models.CharField(max_length=100, null=True)
    logs = models.ManyToManyField(PowerLog, related_name="metrics")
    duration = models.CharField(max_length=75, null=True)

    @property
    def log_links(self):
        """ Get links to logs for this result. """

        links = ""
        for log in self.logs.all():
            name = log.name
            name = name.split('/')[2]

            links = " ".join([
                    links,
                    '<a href="{}" style="display: block;">{}</a>'.format(
                        log.path,
                        name,
                    )
            ])

        return links

    @property
    def log_count(self):
        return self.logs.count()
