# QA Dashboard
# Copyright 2012-2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys

from django.conf.urls.defaults import (
    include,
    patterns,
    url,
)

from django.contrib import admin
admin.autodiscover()


urlpatterns = patterns(
    'smoke.views',
    url(r'^$', 'index', name='index'),
    url(
        r'^smoke/(?P<release>\w+)/$',
        'overview',
        name='smoke_overview'
    ),
    url(
        r'^smoke/$',
        'overview',
        dict(is_flat=True, release='raring'),
        name='smoke_index',
    ),
    url(
        r'^smoke/(?P<release>\w+)/flat/$',
        'overview',
        dict(is_flat=True),
        name='flat'
    ),
    url(
        r'^smoke/(?P<release>\w+)/run/(?P<run_id>\d+)/$',
        'build_overview',
        name='build_overview'
    ),
    url(
        r'^smoke/(?P<release>\w+)/run/(?P<run_id>\d+)/pie/$',
        'build_pie',
        name='build_pie'
    ),
    url(
        r'^smoke/(?P<release>\w+)/run/(?P<run_id>\d+)/image' +
        r'/(?P<image_id>\d+)/$',
        'results',
        name='smoke_results'
    ),
    url(
        r'^smoke/(?P<release>\w+)/run/(?P<run_id>\d+)/image' +
        r'/(?P<image_id>\d+)/pie/$',
        'results_pie',
        name='results_pie'
    ),
    url(
        r'^smoke/(?P<release>\w+)/run/(?P<run_id>\d+)/image' +
        r'/(?P<image_id>\d+)/logs/(?P<result_id>\d+)/$',
        'results_logs',
        name='results_logs'
    ),
)

urlpatterns += patterns(
    'smoke.api',
    url(r'^api/smoke/(?P<release>\w+)/run/$', 'api_runs'),
    url(r'^api/smoke/run/$', 'api_runs'),
    url(r'^api/smoke/run/(?P<run_id>\d+)/$', 'api_run'),
    url(r'^api/smoke/run/(?P<run_id>\d+)/image/$', 'api_images'),
    url(
        r'^api/smoke/run/(?P<run_id>\d+)/image/(?P<image_id>\d+)/$',
        'api_image'
    ),
    url(
        r'^api/smoke/run/(?P<run_id>\d+)/image/(?P<image_id>\d+)/result/$',
        'api_results'
    ),
)

urlpatterns += patterns(
    'sru.views',
    url(r'^sru/$', 'overview', name='sru'),
    url(r'^sru/(?P<release>\w+)/$', 'overview', name='sru_overview'),
    url(
        r'^sru/(?P<release>\w+)/version/(?P<kernel_version>[^/]+)/$',
        'overview_kernel',
        name='sru_overview_kernel'
    ),
)

urlpatterns += patterns(
    'bootspeed.views',
    url(r'^bootspeed/$', 'arch_overview', name='bootspeed_arch'),
    url(
        r'^bootspeed/arch/(?P<arch>\w+)/$',
        'arch_overview',
        name='bootspeed_arch_overview'
    ),
    url(
        r'^bootspeed/arch/(?P<arch>\w+)/image/$',
        'arch_image_list',
        name='arch_image_list'
    ),
    url(
        r'^bootspeed/machine/(?P<machine_id>\d+)/(?P<arch>\w+)/$',
        'machine_data',
        name='machine_data'
    ),
    url(
        r'^bootspeed/machine/(?P<machine_id>\d+)/(?P<arch>\w+)/raw/$',
        'machine_raw_data',
        name='machine_raw_data'
    ),
    url(
        r'^bootspeed/job-bugs/image/$',
        'image_bugs_overview',
        name='bootspeed_image'
    ),
    url(
        r'^bootspeed/job-bugs/image/(?P<image_id>\d+)/$',
        'image_bugs_detail',
        name='bootspeed_image_detail'
    ),
    url(r'^bootspeed/job-bugs/bug/$', 'bug_overview', name='bootspeed_bugs'),
    url(
        r'^bootspeed/job-bugs/bug/(?P<bug_id>\d+)/$',
        'bug_detail',
        name='bootspeed_bug_detail'
    ),
    # Need to remove the other code that goes with this
    #Disabling bootspeed image views for now
    #url(
    #    r'^bootspeed/image/(?P<image_id>\d+)/$',
    #    'image_overview',
    #    name='image_overview'
    #),
    #url(
    #    r'^bootspeed/image/(?P<image_id>\d+)/chart/$',
    #    'build_boot_chart',
    #    name='build_boot_chart'
    #),
)

urlpatterns += patterns(
    'bootspeed.api',
    url(r'^api/bootspeed/arch/$', 'arch_list'),
    url(
        r'^api/bootspeed/arch/(?P<arch>\w+)/$',
        'overall',
        name='api_arch_overall'
    ),
    url(r'^api/bootspeed/image/$', 'image_list'),
    url(
        r'^api/bootspeed/image/(?P<image_id>\d+)/$',
        'image_detail',
        name='api_image_detail'
    ),
    url(
        r'^api/bootspeed/image/(?P<image_id>\d+)/result/$',
        'image_result_list'
    ),
    url(
        r'^api/bootspeed/image/result_count/$',
        'result_count'
    ),
    url(r'^api/bootspeed/machine/$', 'machine_list'),
    url(r'^api/bootspeed/machine/(?P<machine_id>\d+)/$', 'machine_detail'),
    url(
        r'^api/bootspeed/machine/(?P<machine_id>\d+)' +
        r'/(?P<arch>\w+)/results/$',
        'machine_results',
        name='machine_results'
    ),
    url(
        r'^api/bootspeed/machine/(?P<machine_id>\d+)' +
        r'/(?P<arch>\w+)/results/kernel/$',
        'machine_kernel_results',
        name='machine_kernel_results'
    ),
    url(
        r'^api/bootspeed/machine/(?P<machine_id>\d+)' +
        r'/(?P<arch>\w+)/results/kernel_init/$',
        'machine_kernel_init_results',
        name='machine_kernel_init_results'
    ),
    url(
        r'^api/bootspeed/machine/(?P<machine_id>\d+)' +
        r'/(?P<arch>\w+)/results/plumbing/$',
        'machine_plumbing_results',
        name='machine_plumbing_results'
    ),
    url(
        r'^api/bootspeed/machine/(?P<machine_id>\d+)' +
        '/(?P<arch>\w+)/results/xorg/$',
        'machine_xorg_results',
        name='machine_xorg_results'
    ),
    url(
        r'^api/bootspeed/machine/(?P<machine_id>\d+)' +
        r'/(?P<arch>\w+)/results/desktop/$',
        'machine_desktop_results',
        name='machine_desktop_results'
    ),
    url(
        r'^api/bootspeed/machine/(?P<machine_id>\d+)' +
        r'/(?P<arch>\w+)/results/xorg_plumbing/$',
        'machine_xorg_plumbing_results',
        name='machine_xorg_plumbing_results'
    ),
)

urlpatterns += patterns(
    'power.views',
    url(r'^power/$', 'arch_overview', name='power_arch'),
    url(
        r'^power/arch/(?P<arch>\w+)/$',
        'arch_overview',
        name='power_arch_overview'
    ),
    url(
        r'^power/machine/(?P<machine_id>\d+)/(?P<arch>\w+)/metrics/$',
        'machine_detail',
        name='power_machine_detail'
    ),
)

urlpatterns += patterns(
    'power.api',
    url(r'^api/power/images/$', 'images', name='api_power_images'),
    url(r'^api/power/machines/$', 'machines', name='api_power_machines'),
    url(
        r'^api/power/images/(?P<arch>\w+)/$',
        'images',
        name='api_power_images_by_arch'
    ),
    url(
        r'^api/power/image/(?P<image_id>\d+)/$',
        'image_detail',
        name='api_power_image_detail'
    ),
    url(
        r'^api/power/image/(?P<image_id>\d+)' +
        r'/machine/(?P<machine_id>\d+)/metrics/$',
        'image_machine_metrics',
        name='api_power_image_machine_metrics'
    ),
    url(
        r'^api/power/machines/(?P<machine_id>\w+)/(?P<arch>\w+)' +
        r'/metrics/(?P<name>[\w\s]+)/$',
        'machine_metric_results',
        name='machine_metric_results'
    ),
)

urlpatterns += patterns(
    'memory.views',
    url(r'^memory/$', 'arch_overview', name='memory_arch'),
    url(
        r'^memory/arch/(?P<arch>\w+)/$',
        'arch_overview',
        name='memory_arch_overview'
    ),
    url(
        r'^memory/arch/(?P<arch>\w+)/machine/(?P<machine_id>\d+)' +
        r'/install/results/(?P<variant>\w+)/(?P<metric>\w+)/$',
        'machine_image_results',
        name='machine_image_results',
    ),
    url(
        r'^memory/arch/(?P<arch>\w+)/machine/(?P<machine_id>\d+)' +
        r'/upgrade/results/(?P<variant>\w+)/(?P<metric>\w+)/$',
        'machine_upgrade_results',
        name='machine_upgrade_results',
    ),
    url(
        r'^memory/arch/(?P<arch>\w+)/machine/(?P<machine_id>\d+)' +
        r'/install/result/(?P<result_id>\d+)/details/$',
        'machine_image_details',
        name='machine_image_details',
    ),
    url(
        r'^memory/arch/(?P<arch>\w+)/machine/(?P<machine_id>\d+)' +
        r'/upgrade/result/(?P<result_id>\d+)/details/$',
        'machine_upgrade_details',
        name='machine_upgrade_details',
    ),
    url(
        r'^memory/arch/(?P<arch>\w+)/machine/(?P<machine_id>\d+)' +
        r'/install/processes/$',
        'image_process_overview',
        name='memory_image_process_overview',
    ),
    url(
        r'^memory/arch/(?P<arch>\w+)/machine/(?P<machine_id>\d+)' +
        r'/upgrade/processes/$',
        'upgrade_process_overview',
        name='memory_upgrade_process_overview',
    ),
)

urlpatterns += patterns(
    'memory.api',
    url(
        r'^api/memory/images/$',
        'images',
        name='api_memory_images',
    ),
    url(
        r'^api/memory/image/(?P<image_id>\d+)/$',
        'image_detail',
        name='api_memory_image_detail',
    ),
    url(
        r'^api/memory/upgrades/$',
        'upgrades',
        name='api_memory_upgrades',
    ),
    url(
        r'^api/memory/upgrade/(?P<upgrade_id>\d+)/$',
        'upgrade_detail',
        name='api_memory_upgrade_detail',
    ),
    url(
        r'^api/memory/machines/$',
        'machines',
        name='api_memory_machines',
    ),
    url(
        r'^api/memory/machine/(?P<machine_id>\d+)/$',
        'machine_detail',
        name='api_memory_machine_detail',
    ),
    url(
        r'^api/memory/result/(?P<result_id>\d+)/$',
        'result_detail',
        name='api_memory_result_detail',
    ),
    url(
        r'^api/memory/image/(?P<image_id>\d+)/' +
        r'machine/(?P<machine_id>\d+)/results/$',
        'image_machine_results',
        name='api_memory_image_machine_results',
    ),
    url(
        r'^api/memory/image/(?P<image_id>\d+)/' +
        r'machine/(?P<machine_id>\d+)/metrics/$',
        'image_machine_metrics',
        name='api_memory_image_machine_metrics',
    ),
    url(
        r'^api/memory/upgrade/(?P<upgrade_id>\d+)/' +
        r'machine/(?P<machine_id>\d+)/results/$',
        'upgrade_machine_results',
        name='api_memory_upgrade_machine_results',
    ),
    url(
        r'^api/memory/upgrade/(?P<upgrade_id>\d+)/' +
        r'machine/(?P<machine_id>\d+)/metrics/$',
        'upgrade_machine_metrics',
        name='api_memory_upgrade_machine_metrics',
    ),
    url(
        r'^api/memory/upgrade/' +
        r'machine/(?P<machine_id>\d+)/(?P<arch>\w+)/(?P<variant>\w+)/' +
        r'metric/(?P<metric>\w+)/$',
        'upgrade_machine_arch_metrics',
        name='api_memory_upgrade_machine_arch_metrics',
    ),
    url(
        r'^api/memory/image/' +
        r'machine/(?P<machine_id>\d+)/(?P<arch>\w+)/(?P<variant>\w+)/' +
        r'metric/(?P<metric>\w+)/$',
        'image_machine_arch_metrics',
        name='api_memory_image_machine_arch_metrics',
    ),
    url(
        r'^api/memory/image/' +
        r'machine/(?P<machine_id>\d+)/arch/(?P<arch>\w+)/process/$',
        'image_machine_arch_processes',
        name='api_memory_image_machine_arch_processes',
    ),
    url(
        r'^api/memory/image/' +
        r'machine/(?P<machine_id>\d+)/arch/(?P<arch>\w+)/process/' +
        r'(?P<process>.+)/$',
        'image_machine_arch_processes',
        name='api_memory_image_machine_arch_processes',
    ),
    url(
        r'^api/memory/upgrade/' +
        r'machine/(?P<machine_id>\d+)/arch/(?P<arch>\w+)/process/$',
        'upgrade_machine_arch_processes',
        name='api_memory_upgrade_machine_arch_processes',
    ),
    url(
        r'^api/memory/upgrade/' +
        r'machine/(?P<machine_id>\d+)/arch/(?P<arch>\w+)/process/' +
        r'(?P<process>.+)/$',
        'upgrade_machine_arch_processes',
        name='api_memory_upgrade_machine_arch_processes',
    ),
)

urlpatterns += patterns(
    'eventstat.views',
    # NB: (?:...)? denotes an optional parameter
    url(
        r'^power/eventstat/image/(?:arch/(?P<arch>\w+)/)?$',
        'arch_overview',
        name='eventstat_arch_overview',
    ),
    url(
        r'^power/eventstat/(?:arch/(?P<arch>\w+)/)?(?:days/(?P<days>\d+)/)?$',
        'arch_overview',
        name='eventstat_arch_overview',
    ),
    url(
        r'^power/eventstat/arch/(?P<arch>\w+)/machine/(?P<machine_id>\d+)' +
        r'/(?P<method>(install|upgrade))/tasks/(?:type/(?P<task_type>\w+)/)?' +
        r'(?:days/(?P<days>\d+)/)?$',
        'arch_breakdown',
        name='eventstat_arch_breakdown',
    ),
    url(
        r'^power/eventstat/arch/(?P<arch>\w+)/machine/(?P<machine_id>\d+)' +
        r'/(?P<method>(install|upgrade))/(?:days/(?P<days>\d+)/)?' +
        r'task/(?P<task>.*)/$',
        'task_overview',
        name='eventstat_task_overview',
    ),
    url(
        r'^power/eventstat/image/(?P<image_id>\d+)/' +
        r'machine/(?P<machine_id>\d+)' +
        r'/task/(?P<task>.*)/$',
        'image_task_details',
        name='eventstat_image_task_details',
    ),
    url(
        r'^power/eventstat/upgrade/(?P<upgrade_id>\d+)/task/(?P<task>.*)/$',
        'upgrade_task_details',
        name='eventstat_upgrade_task_details',
    ),
    url(
        r'^power/eventstat/image/(?P<image_id>\d+)/' +
        r'machine/(?P<machine_id>\d+)' +
        r'/task_type/(?P<task_type>.*)/details/(?:days/(?P<days>\d+)/)?$',
        'image_details',
        name='eventstat_image_details',
    ),
    url(
        r'^power/eventstat/upgrade/(?P<upgrade_id>\d+)/' +
        r'machine/(?P<machine_id>\d+)' +
        r'/task_type/(?P<task_type>.*)/details/(?:days/(?P<days>\d+)/)?$',
        'upgrade_details',
        name='eventstat_upgrade_details',
    ),
    url(
        r'^power/eventstat/arch/(?P<arch>\w+)/machine/(?P<machine_id>\d+)' +
        r'/(?P<method>(install|upgrade))/' +
        r'(?:days/(?P<days>\d+)/)?task_detail/(?P<task>.*)/$',
        'task_details',
        name='eventstat_task_details',
    ),
    url(
        r'^power/eventstat/arch/(?P<arch>\w+)/machine/(?P<machine_id>\d+)' +
        r'/(?P<method>(install|upgrade))/result/(?P<result_id>\w+)/$',
        'result_details',
        name='eventstat_result_details',
    ),
)

urlpatterns += patterns(
    'eventstat.api',
    url(
        r'^api/power/eventstat/image/(?:arch/(?P<arch>\w+)/)?$',
        'images',
        name='api_eventstat_image',
    ),
    url(
        r'^api/power/eventstat/machine/(?:arch/(?P<arch>\w+)/)?$',
        'machines',
        name='api_eventstat_machine',
    ),
)

urlpatterns += patterns(
    '',
    url(r'^admin/', include(admin.site.urls)),
    (r'^openid/', include('django_openid_auth.urls')),
)

if 'runserver' in sys.argv:
    urlpatterns += patterns(
        '',
        (
            r'^static/(?P<path>.*)$',
            'django.views.static.serve',
            {'document_root': 'static'}
        )
    )

from django.contrib.staticfiles.urls import staticfiles_urlpatterns
urlpatterns += staticfiles_urlpatterns()
