import argparse
import csv
import datetime
import json
import logging
import os
import sys

sys.path.append(os.path.join(os.path.dirname(__file__), '..'))
os.environ['DJANGO_SETTINGS_MODULE'] = 'qa_dashboard.settings'

logging.basicConfig(level=logging.DEBUG)

from bootspeed.utils import add_bootspeed_result

def parse_json_file(filename):
    data = None

    with open(filename, 'r') as jsonfile:
        data = json.load(jsonfile)

    return data

def parse_csv_file(filename):
    data = None

    with open(filename, 'rb') as csvfile:
        # assumses the first row is headers
        csvfile.readline()
        reader = csv.reader(csvfile)
        for row in reader:
            data = {
                    'kernel_init' : row[0],
                    'kernel': row[1],
                    'plumbing': row[2],
                    'xorg': row[3],
                    'desktop': row[4],
                    'boot': row[5],
                    'image_release': row[6],
                    'image_variant': row[7],
                    'image_arch': row[8],
                    'ran_at': row[9],
                    'image_build_number': row[10],
                    'image_md5': row[11],
                    'machine_name': row[12],
                    'machine_mac': row[13],
            }

    return data

if __name__ == "__main__":

    parser = argparse.ArgumentParser(
            description="Script to add bootspeed results"
    )
    parser.add_argument(
            '-t', '--type',
            choices=('csv', 'json'),
            dest='filetype',
            default='csv',
            help="Type of datafile to parse",
    )
    parser.add_argument(
            'datafile',
            metavar='DATAFILE',
            type=str,
            nargs='+',
            help="File to parse",
    )

    args = parser.parse_args()

    if args.filetype == 'csv':
        logging.info("Parsing as CSV file")
        func = parse_csv_file
    elif args.filetype == 'json':
        logging.info("Parsing as JSON file")
        func = parse_json_file

    for filename in args.datafile:
        logging.info("Parsing {}".format(filename))
        data = func(filename)
        if data is not None:
            add_bootspeed_result(data)
