# QA Dashboard
# Copyright 2012-2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import datetime
import random

from django.core.management.base import BaseCommand
from optparse import make_option

from bootspeed.models import (
    Image,
    ImageResult,
    Machine,
)

import logging
logging.basicConfig(level=logging.INFO)


class Command(BaseCommand):
    help = "Create some fake bootspeed results.  Useful for degugging."
    option_list = BaseCommand.option_list + (
        make_option(
            '-r', '--results',
            dest='results',
            default='20',
            help='Number of results per run'
        ),
        make_option(
            '-d', '--days',
            dest='days',
            default='100',
            help='Number of days worth of runs to generate'
        ),
    )

    def handle(self, *args, **options):
        releases = ['precise', 'quantal']
        arches = ['amd64', 'i386']
        variants = ['server', 'desktop', 'mini', 'alternate']
        build_numbers = ['20120909', '20120910', '20120911']

        results_per_run = int(options.get('results'))
        days_of_results = int(options.get('days'))

        days = [
            datetime.datetime.now(
            ) - datetime.timedelta(days=x) for x in range(days_of_results)
        ]

        machines = [
            {
                'name': 'Dell Optiplex 242',
                'mac': '01:02:03:0a:0b',
            },
            {
                'name': 'Nexus 7',
                'mac': '01:02:03:0a:0c',
            },
            {
                'name': 'Dell 242',
                'mac': '01:02:03:0a:0d',
            },
            {
                'name': 'HP 242',
                'mac': '01:02:03:0a:0e',
            },
        ]

        command_start_time = datetime.datetime.now()
        for m in machines:
            machine, created = Machine.objects.get_or_create(
                name=m['name'],
                mac_address=m['mac']
            )

            releases = ['quantal']
            arches = ['amd64', 'i386']
            variants = ['server']
            build_numbers = [date.strftime("%Y%m%d") for date in days]
            build_numbers.append('20120917.1')
            build_numbers.append('20120917.2')

            for release in releases:
                for arch in arches:
                    for variant in variants:
                        for build_number in build_numbers:
                            image, created = Image.objects.get_or_create(
                                release=release,
                                variant=variant,
                                arch=arch,
                                build_number=build_number,
                                md5='fake{}{}{}{}'.format(
                                    build_number,
                                    release,
                                    variant,
                                    arch,
                                ),
                            )

                            now = datetime.datetime.now()
                            for j in range(results_per_run):
                                kernel_init = random.random() * 20
                                kernel = random.random() * 20
                                plumbing = random.random() * 20
                                xorg = random.random() * 20
                                desktop = random.random() * 20
                                kernel_time = kernel_init + kernel
                                boot = kernel_time + plumbing + xorg + desktop
                                ran_at = now - datetime.timedelta(minutes=j)

                                start_time = datetime.datetime.now()
                                ImageResult.objects.create(
                                    image=image,
                                    machine=machine,
                                    kernel=kernel,
                                    kernel_init=kernel_init,
                                    plumbing=plumbing,
                                    xorg=xorg,
                                    desktop=desktop,
                                    boot=boot,
                                    ran_at=ran_at,
                                )
                                now = datetime.datetime.now()
                                time_taken = now - start_time
                                logging.debug(
                                    "ImageResult add time: {}".format(
                                        time_taken
                                    )
                                )
        time_taken = datetime.datetime.now() - command_start_time
        logging.info("ImageResult add time: {}".format(time_taken))
