import datetime
import logging
import os
import random
import time
import sys

sys.path.append(os.path.join(os.path.dirname(__file__), '..'))
os.environ['DJANGO_SETTINGS_MODULE'] = 'qa_dashboard.settings'

logging.basicConfig(level=logging.INFO)

from memory.models import (
    MemoryDetail,
    MemoryImage,
    MemoryMachine,
    MemoryMetric,
    MemoryResult,
    MemoryUpgrade,
)


def add_machines(count=3):

    machines = []

    for i in range(count):
        machines.append(
            MemoryMachine.objects.create(
                name='memory-test-{}'.format(i),
            )
        )

    return machines


def add_images(count=1):

    images = []

    for i in range(count):
        images.append(
            MemoryImage.objects.create(
                arch='amd64',
                variant='desktop',
                release='raring',
                build_number='{}'.format(i),
                md5='fake{}'.format(i),
            )
        )
        images.append(
            MemoryImage.objects.create(
                arch='i386',
                variant='desktop',
                release='raring',
                build_number='{}'.format(i),
                md5='fake1{}'.format(i),
            )
        )

    return images


def add_upgrades(count=1):

    upgrades = []

    for i in range(count):
        upgrades.append(
            MemoryUpgrade.objects.create(
                arch='i386',
                variant='desktop',
                release='raring',
                date=datetime.datetime.now(),
                from_release='raring',
            )
        )
        upgrades.append(
            MemoryUpgrade.objects.create(
                arch='amd64',
                variant='desktop',
                release='raring',
                date=datetime.datetime.now(),
                from_release='raring',
            )
        )

    return upgrades


def add_details(machine, image=None, upgrade=None, count=3):

    if image is None and upgrade is None:
        raise Exception("need either an image or upgrade")

    if image is not None and upgrade is not None:
        raise Exception("can't have an image and an upgrade")

    details = []

    metric_name = 'pss'

    metric = MemoryMetric.objects.create(
        image=image,
        upgrade=upgrade,
        machine=machine,
        name=metric_name,
        ran_at=datetime.datetime.now(),
    )

    for j in range(count):
        date = datetime.datetime.now()
        result = MemoryResult.objects.create(
            image=image,
            upgrade=upgrade,
            machine=machine,
            value=0,
            ran_at=date,
            name=metric_name,
            metric=metric,
        )
        for i in range(count):
            details.append(
                MemoryDetail.objects.create(
                    image=image,
                    upgrade=upgrade,
                    machine=machine,
                    name="detail_name",
                    command="detail_command",
                    uss=random.random() * 100,
                    pss=random.random() * 100,
                    rss=random.random() * 100,
                    vss=random.random() * 100,
                    ran_at=date,
                    result=result,
                )
            )
        time.sleep(2)


def cleanup():

    for klass in [
        MemoryDetail,
        MemoryResult,
        MemoryMetric,
        MemoryMachine,
        MemoryImage,
    ]:
        logging.debug("klass: {}".format(klass))
        klass.objects.all().delete()


def list_stuff():

    for klass in [MemoryImage, MemoryMachine, MemoryDetail]:
        for item in klass.objects.all():
            logging.debug(item)

if __name__ == "__main__":
    cleanup()
    machines = add_machines(count=3)
    images = add_images(count=10)
    upgrades = add_upgrades(count=10)

    for image in images:
        for machine in machines:
            add_details(machine, image=image)

    for upgrade in upgrades:
        for machine in machines:
            add_details(machine, upgrade=upgrade)
