import datetime
import logging
import os
import random
import sys

sys.path.append(os.path.join(os.path.dirname(__file__), '..'))
os.environ['DJANGO_SETTINGS_MODULE'] = 'qa_dashboard.settings'

logging.basicConfig(level=logging.DEBUG)

from power.models import (
        PowerImage,
        PowerMachine,
        PowerMetric,
)


def add_machines(count=1):

    machines = []

    for i in range(count):
        machines.append(PowerMachine.objects.create(
                name='power-test-{}'.format(i),
        ))

    return machines

def add_images(count=1):

    images = []

    for i in range(count):
        images.append(PowerImage.objects.create(
                arch='amd64',
                variant='desktop',
                release='raring',
                build_number='{}'.format(i),
                md5='fake{}'.format(i),
        ))

    return images

def add_metrics(machine, image, count=3):

    metrics = []

    for i in range(count):
        metrics.append(PowerMetric.objects.create(
                ran_at=datetime.datetime.now(),
                machine=machine,
                image=image,
                name="metric {}".format(i),
                minimum=random.random() * 200,
                maximum=300 + random.random() * 100,
                average=200 + random.random() * 100,
                stddev=random.random() * 15,
                duration=random.random() * 100,
        ))

    return metrics

def cleanup():
    PowerImage.objects.all().delete()
    PowerMachine.objects.all().delete()
    PowerMetric.objects.all().delete()

if __name__ == "__main__":
    cleanup()
    machines = add_machines(count=3)
    images = add_images(count=10)

    for image in images:
        for machine in machines:
            add_metrics(machine, image)

