VAGRANT_SETUP=/home/vagrant/vagrant-setup

echo "Does the vagrant-setup directory exist?"
if [ ! -f $VAGRANT_SETUP/_dir ]; then
    echo "Make setup directory"
    mkdir $VAGRANT_SETUP
    touch $VAGRANT_SETUP/_dir
else
    echo "Directory already exists"
fi

echo "Has vagrant been setup before?"
if [ -f $VAGRANT_SETUP/_complete ]; then
    echo "Vagrant is already been setup, no need to install packages"
else
    echo "apt-get update"
    sudo apt-get update
    echo "apt-get update complete"

    echo "Install python-software-properties"
    sudo apt-get -y install python-software-properties bzr
fi

echo "Do we need to add the django ppa?"
if [ ! -f /etc/apt/sources.list.d/qa-dashboard-django-precise.list ]; then
    echo "Add ppa:qa-dashboard/django"
    sudo add-apt-repository ppa:qa-dashboard/django
    touch $VAGRANT_SETUP/_add_ppa
else
    echo "django PPA already exists"
fi

echo "Do we need to add the flake8 ppa?"
if [ ! -f /etc/apt/sources.list.d/chrisjohnston-flake8-precise.list ]; then
    echo "Adding ppa:chrisjohnston/flake8"
    sudo add-apt-repository ppa:chrisjohnston/flake8
    touch $VAGRANT_SETUP/_add_ppa
else
    echo "flake8 ppa already exists"
fi

echo "Do we need to run apt-get update?"
if [ ! -f $VAGRANT_SETUP/_add_ppa ]; then
    echo "apt-get update not needed"
else
    echo "apt-get update"
    sudo apt-get update
    echo "apt-get update complete"
    rm $VAGRANT_SETUP/_add_ppa
fi

if [ -f $VAGRANT_SETUP/_complete ]; then
    echo "Vagrant is already been setup, no need to install packages"
else
    echo "Install packages"
    sudo apt-get -y install python python-dev postgresql python-psycopg2 python-django python-django-south python-matplotlib python-yaml django-tables python-flake8 python-django-auth-openid
fi

echo "Does the postgres config need updating?"
sudo grep -q "local   all             all                                     peer" /etc/postgresql/9.1/main/pg_hba.conf; [ $? -eq 0 ] && touch $VAGRANT_SETUP/postgres || echo "config is correct"
if [ -f $VAGRANT_SETUP/postgres ]; then
    echo "Update postgres config"
    sudo sed -i "s/local   all             all                                     peer/local   all             all                                     md5/g" /etc/postgresql/9.1/main/pg_hba.conf
    echo "Restart postgres"
    sudo service postgresql restart
fi

echo "Is there already a database dump? If not, download it"
if [ ! -f $VAGRANT_SETUP/dash.sql ]; then
        echo "Download database"
        wget -q http://people.ubuntu.com/~chrisjohnston/qa_dash/dash.tgz -O $VAGRANT_SETUP/dash.tgz
        tar xzf $VAGRANT_SETUP/dash.tgz -C $VAGRANT_SETUP
else
    echo "Database already exists"
fi

if [ ! -f $VAGRANT_SETUP/_dash_db_created ]; then
    echo "create user qa_user with password 'qa_pass';" | sudo -u postgres psql
    echo "ALTER USER qa_user CREATEDB;" | sudo -u postgres psql
    echo "UPDATE pg_database SET datallowconn = TRUE WHERE datname = 'template0';" | sudo -u postgres psql
    echo "create database qa_dashboard owner qa_user;" | sudo -u postgres psql template0
    echo "import database"
    PGPASSWORD=qa_pass psql -h localhost -U qa_user -d qa_dashboard -f $VAGRANT_SETUP/dash.sql

    touch $VAGRANT_SETUP/_dash_db_created
fi

echo "Do I need to create local_settings.py?"
if [ ! -f dash/local_settings.py ]; then
    echo "setup local_settings.py"
    cp dash/local_settings.py.example dash/local_settings.py
else
    echo "local_settings.py already exists"
fi

echo "Setup complete!"
touch $VAGRANT_SETUP/_complete
