# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from smoke.models import (
    Build,
    Run,
    Result,
    ResultLog,
)

from django.contrib import admin


class BuildAdmin(admin.ModelAdmin):
    list_filter = ['variant', 'arch']
    search_fields = [
        'name',
        'run__build_no',
        'run__release',
    ]
    list_display = ('run', 'variant', 'arch')
    ordering = ['-run']


class RunAdmin(admin.ModelAdmin):
    list_display = ('build_no', 'release')
    list_filter = ['release', 'flavor']
    search_fields = ['build_no']
    date_hierarchy = 'ran_at'
    ordering = ['-build_no']


class ResultAdmin(admin.ModelAdmin):
    list_display = (
        'build',
        'name',
        'fail_count',
        'error_count',
        'pass_count',
        'total_count',
        'ran_at',
    )
    list_filter = ['name']
    search_fields = ['name']
    date_hierarchy = 'ran_at'
    ordering = ['build']


class ResultLogAdmin(admin.ModelAdmin):
    list_display = ('result', 'path')
    search_fields = ['path', 'result__name']


admin.site.register(Build, BuildAdmin)
admin.site.register(Run, RunAdmin)
admin.site.register(Result, ResultAdmin)
admin.site.register(ResultLog, ResultLogAdmin)
