# QA Dashboard
# Copyright 2012-2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import json
from django.http import HttpResponse, Http404

from django.views.decorators.http import (
    require_GET,
)

from smoke.models import (
    Build,
    Run,
    Result,
)

from common.utils import (
    JSONResponse,
    MySerializer,
    get_verbose,
)


@require_GET
def api_runs(request, release=None):
    runs = Run.objects.all().exclude(publish=False)

    if release is not None:
        runs = runs.filter(release=release)

    use_extra_fields = get_verbose(request)
    serializer = MySerializer(use_extra_fields=get_verbose(request))
    data = serializer.serialize(runs)
    return HttpResponse(data, content_type='application/json')


@require_GET
def api_run(request, run_id):
    """
    For some magical reason, Django won't serialize if you use .get(). It
    really needs a queryset, hence the .filter()
    """
    run = Run.objects.filter(id=run_id).exclude(publish=False)
    serializer = MySerializer(use_extra_fields=get_verbose(request, True))
    data = serializer.serialize(run)
    return HttpResponse(data, content_type='application/json')


@require_GET
def api_images(request, run_id):
    try:
        run = Run.objects.exclude(publish=False).get(id=run_id)
    except Run.DoesNotExist:
        raise Http404
    images = run.build_set.all().exclude(publish=False)
    serializer = MySerializer(use_extra_fields=get_verbose(request))
    data = serializer.serialize(images)
    return HttpResponse(data, content_type='application/json')


@require_GET
def api_image(request, run_id, image_id):
    """
    For some magical reason, Django won't serialize if you use .get(). It
    really needs a queryset, hence the .filter()
    """
    image = Build.objects.filter(id=image_id).exclude(publish=False)
    serializer = MySerializer(use_extra_fields=get_verbose(request, True))
    data = serializer.serialize(image)
    return HttpResponse(data, content_type='application/json')


@require_GET
def api_results(request, run_id, image_id):
    try:
        image = Build.objects.exclude(publish=False).get(id=image_id)
    except Build.DoesNotExist:
        raise Http404
    results = image.result_set.all().exclude(publish=False)
    serializer = MySerializer(use_extra_fields=get_verbose(request))
    data = serializer.serialize(results)
    return HttpResponse(data, content_type='application/json')
